<?php
/*
Author: Anggun Pribadi
URL: http://circathemes.me/
*/

if ( ! function_exists( 'lightly_setup' ) ) :

function lightly_setup() {

    /************* LOAD TEXTDOMAIN *************/

    load_theme_textdomain( 'lightly', get_template_directory().'/languages' );

    $locale = get_locale();
    $locale_file = get_template_directory()."/languages/$locale.php";
    if ( is_readable($locale_file) )
        require_once($locale_file);

    add_theme_support( 'title-tag' );
    
}
endif;
add_action( 'after_setup_theme', 'lightly_setup' );

/*
Initial WordPress load, contains used global variable, include files call etc.
*/

/**
 * Proper way to enqueue scripts and styles
 */
function lightly_scripts() {
    wp_enqueue_style( 'style', get_stylesheet_uri() );
}
add_action( 'wp_enqueue_scripts', 'lightly_scripts' );

// Call required PHP files
require_once('inc/circathemes-helper.php');
require_once('inc/metaboxes.php');
require_once('inc/widgets/recent_posts.php');
require_once('inc/widgets/recent_comments.php');
require_once('inc/widgets/tabs.php');
require_once('inc/widgets/video.php');
require_once('inc/widgets/flickr.php');
require_once('inc/widgets/ad125.php');

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/customizer-simple.php';

if ( ! isset( $content_width ) ) $content_width = 710;

/************* ACTIVE SIDEBARS ********************/

// Sidebars & Widgetizes Areas
function lightly_register_sidebars() {
	register_sidebar(array(
		'id' => 'sidebar1',
		'name' => __( 'Sidebar 1','lightly' ),
		'description' => __( 'The first (primary) sidebar.','lightly' ),
		'before_widget' => '<div id="%1$s" class="widget clearfix %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle"><span>',
		'after_title' => '</span></h4>'
	));

	register_sidebar(array(
		'id' => 'footer-sidebar1',
		'name' => __( 'Footer Sidebar 1','lightly' ),
		'description' => __( 'First footer widget area.','lightly' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle"><span>',
		'after_title' => '</span></h4>',
		'empty_title'=> '<h4 class="widgettitle hide-title"><span>',
	));

	register_sidebar(array(
		'id' => 'footer-sidebar2',
		'name' => __( 'Footer Sidebar 2','lightly' ),
		'description' => __( 'Second footer widget area','lightly' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle"><span>',
		'after_title' => '</span></h4>',
		'empty_title'=> '<h4 class="widgettitle hide-title"><span>',
	));

	register_sidebar(array(
		'id' => 'footer-sidebar3',
		'name' => __( 'Footer Sidebar 3','lightly' ),
		'description' => __( 'Third footer widget area','lightly' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle"><span>',
		'after_title' => '</span></h4>',
		'empty_title'=> '<h4 class="widgettitle hide-title"><span>',
	));

	register_sidebar(array(
		'id' => 'footer-sidebar4',
		'name' => __( 'Footer Sidebar 4','lightly' ),
		'description' => __( 'Fourth footer widget area','lightly' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle"><span>',
		'after_title' => '</span></h4>',
		'empty_title'=> '<h4 class="widgettitle hide-title"><span>',
	));
    
	register_sidebar(array(
		'id' => 'header-sidebar',
		'name' => __( 'Header Sidebar','lightly' ),
		'description' => __( 'Widget area on the header, best use for advertisement.','lightly' ),
		'before_widget' => '<div id="%1$s" class="widget clearfix %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widgettitle"><span>',
		'after_title' => '</span></h4>'
	));
} // don't remove this bracket!


/************* COMMENT LAYOUT *********************/
		
// Comment Layout
function lightly_comments($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="clearfix">
			<header class="comment-author vcard">
				<?php echo get_avatar($comment,$size='45' ); ?>
				<?php printf(__('<cite class="fn">%s</cite>', 'lightly'), get_comment_author_link()) ?>
				<p class="meta"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>"><?php printf(__('%1$s', 'lightly'), get_comment_date(get_option('date_format')). ' ' .  get_comment_time(get_option('time_format'))) ?></a></p>
				<?php edit_comment_link(__('(Edit)', 'lightly'),'  ','') ?>
			</header>
			<?php if ($comment->comment_approved == '0') : ?>
       			<div class="help">
          			<p><?php _e('Your comment is awaiting moderation.', 'lightly') ?></p>
          		</div>
			<?php endif; ?>
			<section class="comment_content clearfix">
				<?php comment_text() ?>
			</section>
			<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
		</article>
    <!-- </li> is added by wordpress automatically -->
<?php
} // don't remove this bracket!

/************* SEARCH FORM LAYOUT *****************/

// Search Form
function lightly_wpsearch($form) {
    $form = '<form role="search" method="get" id="searchform" action="' . esc_url( home_url( '/' ) ) . '" >
    <label class="screen-reader-text" for="s">' . __('Search for:', 'lightly') . '</label>
    <input type="text" value="' . get_search_query() . '" name="s" id="s" placeholder="' . __('Type your search here', 'lightly'). '" />
    <input type="submit" id="searchsubmit" value="'. __('Search', 'lightly') .'" />
    </form>';
    return $form;
}
?>